==> client-java-api-9.0.2-sources.jar: io/kubernetes/client/openapi/models/NetworkingV1beta1IngressSpecFluent.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Fluent;
import java.util.Collection;

public interface NetworkingV1beta1IngressSpecFluent<A extends NetworkingV1beta1IngressSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBackend instead.
 * @return The buildable object.
 */
@Deprecated public NetworkingV1beta1IngressBackend getBackend();
    public NetworkingV1beta1IngressBackend buildBackend();
    public A withBackend(NetworkingV1beta1IngressBackend backend);
    public Boolean hasBackend();
    public NetworkingV1beta1IngressSpecFluent.BackendNested<A> withNewBackend();
    public NetworkingV1beta1IngressSpecFluent.BackendNested<A> withNewBackendLike(NetworkingV1beta1IngressBackend item);
    public NetworkingV1beta1IngressSpecFluent.BackendNested<A> editBackend();
    public NetworkingV1beta1IngressSpecFluent.BackendNested<A> editOrNewBackend();
    public NetworkingV1beta1IngressSpecFluent.BackendNested<A> editOrNewBackendLike(NetworkingV1beta1IngressBackend item);
    public A addToRules(int index,NetworkingV1beta1IngressRule item);
    public A setToRules(int index,NetworkingV1beta1IngressRule item);
    public A addToRules(NetworkingV1beta1IngressRule... items);
    public A addAllToRules(Collection<NetworkingV1beta1IngressRule> items);
    public A removeFromRules(NetworkingV1beta1IngressRule... items);
    public A removeAllFromRules(Collection<NetworkingV1beta1IngressRule> items);
    public A removeMatchingFromRules(io.kubernetes.client.fluent.Predicate<NetworkingV1beta1IngressRuleBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<NetworkingV1beta1IngressRule> getRules();
    public List<NetworkingV1beta1IngressRule> buildRules();
    public NetworkingV1beta1IngressRule buildRule(int index);
    public NetworkingV1beta1IngressRule buildFirstRule();
    public NetworkingV1beta1IngressRule buildLastRule();
    public NetworkingV1beta1IngressRule buildMatchingRule(io.kubernetes.client.fluent.Predicate<NetworkingV1beta1IngressRuleBuilder> predicate);
    public Boolean hasMatchingRule(io.kubernetes.client.fluent.Predicate<NetworkingV1beta1IngressRuleBuilder> predicate);
    public A withRules(List<NetworkingV1beta1IngressRule> rules);
    public A withRules(NetworkingV1beta1IngressRule... rules);
    public Boolean hasRules();
    public NetworkingV1beta1IngressSpecFluent.RulesNested<A> addNewRule();
    public NetworkingV1beta1IngressSpecFluent.RulesNested<A> addNewRuleLike(NetworkingV1beta1IngressRule item);
    public NetworkingV1beta1IngressSpecFluent.RulesNested<A> setNewRuleLike(int index,NetworkingV1beta1IngressRule item);
    public NetworkingV1beta1IngressSpecFluent.RulesNested<A> editRule(int index);
    public NetworkingV1beta1IngressSpecFluent.RulesNested<A> editFirstRule();
    public NetworkingV1beta1IngressSpecFluent.RulesNested<A> editLastRule();
    public NetworkingV1beta1IngressSpecFluent.RulesNested<A> editMatchingRule(io.kubernetes.client.fluent.Predicate<NetworkingV1beta1IngressRuleBuilder> predicate);
    public A addToTls(int index,NetworkingV1beta1IngressTLS item);
    public A setToTls(int index,NetworkingV1beta1IngressTLS item);
    public A addToTls(NetworkingV1beta1IngressTLS... items);
    public A addAllToTls(Collection<NetworkingV1beta1IngressTLS> items);
    public A removeFromTls(NetworkingV1beta1IngressTLS... items);
    public A removeAllFromTls(Collection<NetworkingV1beta1IngressTLS> items);
    public A removeMatchingFromTls(io.kubernetes.client.fluent.Predicate<NetworkingV1beta1IngressTLSBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTls instead.
 * @return The buildable object.
 */
@Deprecated public List<NetworkingV1beta1IngressTLS> getTls();
    public List<NetworkingV1beta1IngressTLS> buildTls();
    public NetworkingV1beta1IngressTLS buildTl(int index);
    public NetworkingV1beta1IngressTLS buildFirstTl();
    public NetworkingV1beta1IngressTLS buildLastTl();
    public NetworkingV1beta1IngressTLS buildMatchingTl(io.kubernetes.client.fluent.Predicate<NetworkingV1beta1IngressTLSBuilder> predicate);
    public Boolean hasMatchingTl(io.kubernetes.client.fluent.Predicate<NetworkingV1beta1IngressTLSBuilder> predicate);
    public A withTls(List<NetworkingV1beta1IngressTLS> tls);
    public A withTls(NetworkingV1beta1IngressTLS... tls);
    public Boolean hasTls();
    public NetworkingV1beta1IngressSpecFluent.TlsNested<A> addNewTl();
    public NetworkingV1beta1IngressSpecFluent.TlsNested<A> addNewTlLike(NetworkingV1beta1IngressTLS item);
    public NetworkingV1beta1IngressSpecFluent.TlsNested<A> setNewTlLike(int index,NetworkingV1beta1IngressTLS item);
    public NetworkingV1beta1IngressSpecFluent.TlsNested<A> editTl(int index);
    public NetworkingV1beta1IngressSpecFluent.TlsNested<A> editFirstTl();
    public NetworkingV1beta1IngressSpecFluent.TlsNested<A> editLastTl();
    public NetworkingV1beta1IngressSpecFluent.TlsNested<A> editMatchingTl(io.kubernetes.client.fluent.Predicate<NetworkingV1beta1IngressTLSBuilder> predicate);

    public interface BackendNested<N> extends io.kubernetes.client.fluent.Nested<N>,NetworkingV1beta1IngressBackendFluent<NetworkingV1beta1IngressSpecFluent.BackendNested<N>>{

        
    public N and();    public N endBackend();
}
    public interface RulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,NetworkingV1beta1IngressRuleFluent<NetworkingV1beta1IngressSpecFluent.RulesNested<N>>{

        
    public N and();    public N endRule();
}
    public interface TlsNested<N> extends io.kubernetes.client.fluent.Nested<N>,NetworkingV1beta1IngressTLSFluent<NetworkingV1beta1IngressSpecFluent.TlsNested<N>>{

        
    public N and();    public N endTl();
}


}

==> client-java-api-10.0.0-sources.jar: io/kubernetes/client/openapi/models/NetworkingV1beta1IngressSpecFluent.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;

public interface NetworkingV1beta1IngressSpecFluent<A extends NetworkingV1beta1IngressSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildBackend instead.
 * @return The buildable object.
 */
@Deprecated public NetworkingV1beta1IngressBackend getBackend();
    public NetworkingV1beta1IngressBackend buildBackend();
    public A withBackend(NetworkingV1beta1IngressBackend backend);
    public Boolean hasBackend();
    public NetworkingV1beta1IngressSpecFluent.BackendNested<A> withNewBackend();
    public NetworkingV1beta1IngressSpecFluent.BackendNested<A> withNewBackendLike(NetworkingV1beta1IngressBackend item);
    public NetworkingV1beta1IngressSpecFluent.BackendNested<A> editBackend();
    public NetworkingV1beta1IngressSpecFluent.BackendNested<A> editOrNewBackend();
    public NetworkingV1beta1IngressSpecFluent.BackendNested<A> editOrNewBackendLike(NetworkingV1beta1IngressBackend item);
    public String getIngressClassName();
    public A withIngressClassName(String ingressClassName);
    public Boolean hasIngressClassName();
    public A withNewIngressClassName(String arg1);
    public A withNewIngressClassName(StringBuilder arg1);
    public A withNewIngressClassName(StringBuffer arg1);
    public A addToRules(int index,NetworkingV1beta1IngressRule item);
    public A setToRules(int index,NetworkingV1beta1IngressRule item);
    public A addToRules(NetworkingV1beta1IngressRule... items);
    public A addAllToRules(Collection<NetworkingV1beta1IngressRule> items);
    public A removeFromRules(NetworkingV1beta1IngressRule... items);
    public A removeAllFromRules(Collection<NetworkingV1beta1IngressRule> items);
    public A removeMatchingFromRules(io.kubernetes.client.fluent.Predicate<NetworkingV1beta1IngressRuleBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<NetworkingV1beta1IngressRule> getRules();
    public List<NetworkingV1beta1IngressRule> buildRules();
    public NetworkingV1beta1IngressRule buildRule(int index);
    public NetworkingV1beta1IngressRule buildFirstRule();
    public NetworkingV1beta1IngressRule buildLastRule();
    public NetworkingV1beta1IngressRule buildMatchingRule(io.kubernetes.client.fluent.Predicate<NetworkingV1beta1IngressRuleBuilder> predicate);
    public Boolean hasMatchingRule(io.kubernetes.client.fluent.Predicate<NetworkingV1beta1IngressRuleBuilder> predicate);
    public A withRules(List<NetworkingV1beta1IngressRule> rules);
    public A withRules(NetworkingV1beta1IngressRule... rules);
    public Boolean hasRules();
    public NetworkingV1beta1IngressSpecFluent.RulesNested<A> addNewRule();
    public NetworkingV1beta1IngressSpecFluent.RulesNested<A> addNewRuleLike(NetworkingV1beta1IngressRule item);
    public NetworkingV1beta1IngressSpecFluent.RulesNested<A> setNewRuleLike(int index,NetworkingV1beta1IngressRule item);
    public NetworkingV1beta1IngressSpecFluent.RulesNested<A> editRule(int index);
    public NetworkingV1beta1IngressSpecFluent.RulesNested<A> editFirstRule();
    public NetworkingV1beta1IngressSpecFluent.RulesNested<A> editLastRule();
    public NetworkingV1beta1IngressSpecFluent.RulesNested<A> editMatchingRule(io.kubernetes.client.fluent.Predicate<NetworkingV1beta1IngressRuleBuilder> predicate);
    public A addToTls(int index,NetworkingV1beta1IngressTLS item);
    public A setToTls(int index,NetworkingV1beta1IngressTLS item);
    public A addToTls(NetworkingV1beta1IngressTLS... items);
    public A addAllToTls(Collection<NetworkingV1beta1IngressTLS> items);
    public A removeFromTls(NetworkingV1beta1IngressTLS... items);
    public A removeAllFromTls(Collection<NetworkingV1beta1IngressTLS> items);
    public A removeMatchingFromTls(io.kubernetes.client.fluent.Predicate<NetworkingV1beta1IngressTLSBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTls instead.
 * @return The buildable object.
 */
@Deprecated public List<NetworkingV1beta1IngressTLS> getTls();
    public List<NetworkingV1beta1IngressTLS> buildTls();
    public NetworkingV1beta1IngressTLS buildTl(int index);
    public NetworkingV1beta1IngressTLS buildFirstTl();
    public NetworkingV1beta1IngressTLS buildLastTl();
    public NetworkingV1beta1IngressTLS buildMatchingTl(io.kubernetes.client.fluent.Predicate<NetworkingV1beta1IngressTLSBuilder> predicate);
    public Boolean hasMatchingTl(io.kubernetes.client.fluent.Predicate<NetworkingV1beta1IngressTLSBuilder> predicate);
    public A withTls(List<NetworkingV1beta1IngressTLS> tls);
    public A withTls(NetworkingV1beta1IngressTLS... tls);
    public Boolean hasTls();
    public NetworkingV1beta1IngressSpecFluent.TlsNested<A> addNewTl();
    public NetworkingV1beta1IngressSpecFluent.TlsNested<A> addNewTlLike(NetworkingV1beta1IngressTLS item);
    public NetworkingV1beta1IngressSpecFluent.TlsNested<A> setNewTlLike(int index,NetworkingV1beta1IngressTLS item);
    public NetworkingV1beta1IngressSpecFluent.TlsNested<A> editTl(int index);
    public NetworkingV1beta1IngressSpecFluent.TlsNested<A> editFirstTl();
    public NetworkingV1beta1IngressSpecFluent.TlsNested<A> editLastTl();
    public NetworkingV1beta1IngressSpecFluent.TlsNested<A> editMatchingTl(io.kubernetes.client.fluent.Predicate<NetworkingV1beta1IngressTLSBuilder> predicate);

    public interface BackendNested<N> extends io.kubernetes.client.fluent.Nested<N>,NetworkingV1beta1IngressBackendFluent<NetworkingV1beta1IngressSpecFluent.BackendNested<N>>{

        
    public N and();    public N endBackend();
}
    public interface RulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,NetworkingV1beta1IngressRuleFluent<NetworkingV1beta1IngressSpecFluent.RulesNested<N>>{

        
    public N and();    public N endRule();
}
    public interface TlsNested<N> extends io.kubernetes.client.fluent.Nested<N>,NetworkingV1beta1IngressTLSFluent<NetworkingV1beta1IngressSpecFluent.TlsNested<N>>{

        
    public N and();    public N endTl();
}


}
